filelock: Platform independent file lock
========================================

Description
-----------

Platform independent file lock

License
-------

Public Domain <http://unlicense.org>

Upstream Contact
----------------

https://pypi.org/project/filelock/

